# Project Branding


<img src="https://github.com/SuperCowPowers/sageworks/assets/4806709/4cdd3700-a9d8-441f-a27d-3da1038c7c4d" style="float: right; width: 500px; height: auto; padding: 10px 0px 0px 20px">

The SageWorks Dashboard can be customized extensively. Using SageWorks **Project Branding** allows you to change page headers, titles, and logos to match your project. All user interfaces will reflect your project name and company logos. 


## Contact Us
Contact us on our [Discord](https://discord.gg/WHAJuz8sw8) channel, we're happy to answer any questions that you might have about **SageWorks** and accelerating your AWS ML Pipelines. You can also send us email at [SageWorks Info](mailto:sageworks@supercowpowers.com) or  [SageWorks Sales](mailto:sales@supercowpowers.com).
